<?php
/**
 * mosKingyoyaAbstract クラススクリプト
 * 
 * 金魚屋開発支援シリーズ
 *
 * @package Joomla
 * @component com_kingyoya_mosabstract
 * @copyright (C) 2008 金魚屋見聞録
 * @author 金魚屋・Ｊ・龍角
 * @version 1.0.0
 */

// no direct access
defined( '_VALID_MOS' ) or die( 'Restricted access' );

/**
 * 開発支援抽象クラス
 * @see mosDBTable, mosUser
 * @abstract
 */
class mosKingyoyaAbstract extends mosDBTable {

	/** @var int id PRIMARY KEY */
	var $id;

	/** @var int created timestamp */
	var $created;

	/** @var int created by #__users.id */
	var $created_by;

	/** @var int modified timestamp */
	var $modified;

	/** @var int modified by #__users.id */
	var $modified_by;

	/**
	 * コンストラクタ
	 * @param string tablename
	 * @param database &db
	 */
	function mosKingyoyaAbstract($tablename, &$db) {
		if (!$db || !is_object($db)) {
			trigger_error('Failed get database', E_USER_WARNING);
			return;
		}
		if (!$tablename || !is_string($tablename)) {
			trigger_error('Failed get table name', E_USER_WARNING);
			return;
		}
		parent::mosDBTable($tablename, 'id', $db);
	}

	/**
	 * id をID に持つデータを読み込み
	 * @param int id
	 * @return boolean True if id's data exists, false otherwise
	 */
	function load($id) {
		$id = (int) $id;
		if (!$id) {
			trigger_error('Failed get id for load', E_USER_WARNING);
			return false;
		}
		$result = parent::load($id);
		if (!$result) return false;
		$this->id = (int) $this->id;
		return true;
	}

	/**
	 * メンバー変数に格納された値を登録する
	 * @return boolean True if success stored,false otherwise
	 */
	function store() {
		if (!$this->check()) {
			return false;
		}
		global $my;
		$userid = (int) $my->id;
		$now = time();
		if (!$this->id) {
			/*
			 * 新規登録
			 */
			$this->created = $now;
			$this->created_by = $userid;
		}
		$this->modified = $now;
		$this->modified_by = $userid;
		$result = parent::store();
		if (!$result) {
			trigger_error("Failed store: ".$this->getError(), E_USER_WARNING);
			return false;
		}
		if (!$this->id) {
			/*
			 * 新規登録のID取得
			 */
			$this->id = (int) $this->_db->insertid();
		}
		return true;
	}

	/**
	 * ID を取得
	 * @return int id
	 */
	function id() {
		return (int) $this->id;
	}

	/**
	 * 登録日時を取得
	 * @param string date_format
	 * @return mixed created timestamp or formated string
	 */
	function created($date_format = null) {
		if (!$date_format) {
			return (int) $this->created;
		} else {
			return date($date_format, $this->created);
		}
	}

	/**
	 * 登録ユーザを取得
	 * @param string key
	 * @return mosUser created user or user value
	 */
	function created_by($key = null) {
		$id = (int) $this->created_by;
		if (!$id) return null;
		$user = new mosUser($this->_db);
		$result = $user->load($id);
		if (!$result) {
			trigger_error(
					"Failed load created user: ".$user->getError()
					, E_USER_WARNING
				);
			return null;
		}
		return $key ? $user->$key : $user;
	}

	/**
	 * 更新日時を取得
	 * @param string date_format
	 * @return mixed modified timestamp or formated string
	 */
	function modified($date_format = null) {
		if (!$date_format) {
			return (int) $this->modified;
		} else {
			return date($date_format, $this->modified);
		}
	}

	/**
	 * 更新ユーザを取得
	 * @param string key
	 * @return mosUser modified user or user value
	 */
	function modified_by($key = null) {
		$id = (int) $this->modified_by;
		if (!$id) return null;
		$user = new mosUser($this->_db);
		$result = $user->load($id);
		if (!$result) {
			trigger_error(
					"Failed load modified user: ".$user->getError()
					, E_USER_WARNING
				);
			return null;
		}
		return $key ? $user->$key : $user;
	}
}
